@@ -2,7 +2,7 @@ import pytest
 import numpy as np
 from spotPython.utils.init import fun_control_init
 from spotPython.hyperparameters.values import get_bound_values
-from spotPython.hyperparameters.values import get_fun_control_key_value, set_fun_control_key_value
+from spotPython.hyperparameters.values import get_control_key_value, set_control_key_value
 
 
 def test_get_bound_values():
@@ -29,35 +29,35 @@ def test_get_bound_values():
         get_bound_values(fun_control, "invalid", as_list=True)
 
 
-def test_set_fun_control_key_value():
+def test_set_control_key_value():
     fun_control = fun_control_init()
 
     # Test when key is not in fun_control and replace is False
-    set_fun_control_key_value(fun_control, "key1", "value1")
+    set_control_key_value(fun_control, "key1", "value1")
     assert fun_control["key1"] == "value1"
 
     # Test when key is in fun_control and replace is False
-    set_fun_control_key_value(fun_control, "key1", "value2")
+    set_control_key_value(fun_control, "key1", "value2")
     assert fun_control["key1"] == "value1"
 
     # Test when key is in fun_control and replace is True
-    set_fun_control_key_value(fun_control, "key1", "value2", replace=True)
+    set_control_key_value(fun_control, "key1", "value2", replace=True)
     assert fun_control["key1"] == "value2"
 
     # Test when key is not in fun_control and replace is True
-    set_fun_control_key_value(fun_control, "key2", "value3", replace=True)
+    set_control_key_value(fun_control, "key2", "value3", replace=True)
     assert fun_control["key2"] == "value3"
 
-def test_get_fun_control_key_value():
+def test_get_control_key_value():
     fun_control = fun_control_init()
 
     # Test when key is not in fun_control
-    assert get_fun_control_key_value(fun_control, "key1") is None
+    assert get_control_key_value(fun_control, "key1") is None
 
     # Test when fun_control is None
-    assert get_fun_control_key_value() is None
+    assert get_control_key_value() is None
 
     # Test when key is in fun_control
-    set_fun_control_key_value(fun_control, "key1", "value1")
-    assert get_fun_control_key_value(fun_control, "key1") == "value1"
+    set_control_key_value(fun_control, "key1", "value1")
+    assert get_control_key_value(fun_control, "key1") == "value1"
     
\ No newline at end of file
